==> dl.php?src=linea21_1_6.zip: linea21/languages/en/lang_system.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$lang['theme']['name']='Name';
$lang['theme']['author']='Author';
$lang['theme']['version']='Version';
$lang['theme']['compatibility']='Compatibility';
$lang['theme']['description']='Description';

$lang['upload']['CheckExtImage'] = "Upload not allowed. Please, check the extension";
$lang['upload']['upload_size'] = "The file you want to upload is too big. Maximal size is  : %s";
$lang['upload']['wrong_ext'] = "File type not allowed.<br />See allowed extensions : <em>%s</em>";
$lang['upload']['confirmed'] = "Upload successful";
$lang['upload']['error'] = "Unexpected upload error.";
$lang['upload']['addfiles'] = "Add files";

$lang['upload']['prohibited_transfert'] = "Transfer method is forbidden";
$lang['upload']['file_exist_yet'] = "File already exists";

$lang['upload']['ftp_conn_failed'] = "FTP connexion failed";
$lang['upload']['ftp_user'] ='ftp_user';
$lang['upload']['ftp_conn'] ='FTP connexion try';
$lang['upload']['ftp_transfert_error'] ='FTP transfer error';

$lang['upload']['no_resize'] ='Document is not a resizable picture.';

$lang['system']['mod']="Edit settings";
$lang['system']['title_theme']='interface theme (look and feel)';
$lang['system']['title_release']='Global settings';
$lang['system']['title_db']='Database settings';
$lang['system']['title_php_info']='PHP Settings (read only)';
$lang['system']['confirm_mod'] = "Configuration file successfully updated\n";
$lang['system']['help_list1']="Click on settings parameter to display more informations";
$lang['system']['help_list2']="Edit parameters by clicking on the edit icon linked in";
$lang['system']['help_list3']="To perform search, just click the 'search' link";
$lang['system']['list']= "Settings list";
$lang['system']['help_mod1']="To edit a parameter, please insert the required informations in the form above";
$lang['system']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['system']['help_mod3']="After checking summary, click the \'review settings\' button to make changes";
$lang['system']['permission_check']="Permissions check";
$lang['system']['permission_writable']="Write permissions on %s folder";
$lang['system']['permission_ok']="Authorized";
$lang['system']['permission_warn']="Unauthorized";

//traductions pour les fichiers de configuration config_db et config_release

$lang['system']['DB_HOST'] ="Database host, default : localhost";
$lang['system']['DB_USER'] = "Database user, default : linea";
$lang['system']['DB_PASS'] = "Database password, default : linea";
$lang['system']['DB_NAME'] = "Database base name, default : linea";
$lang['system']['DB_ADMINMAIL'] = "Database administrator email | default : -1 | option : -1 / adress@email.com";
$lang['system']['DATABASE'] = "T_ : primary table prefix / J_ : join table prefix";
$lang['system']['RELEASE_SETTINGS'] = 'Global settings';
$lang['system']['LINEA_VERSION'] = 'Linea21 version';
$lang['system']['U_L'] = 'Language | default : fr | option : en / fr';
$lang['system']['CHARSET'] = 'Charset encoding | default : utf-8 | option : utf-8';
$lang['system']['USER_COMMUNITY'] = 'Community id number';
$lang['system']['SELECT_LIMIT'] = 'Maximum limit for query select | default : 20';
$lang['system']['MAX_SCALE_LEVEL'] = 'Maximum scale level | default : 5';
$lang['system']['THEME_PUBLIC'] = 'Theme used in front-end';
$lang['system']['THEME_ADMIN'] = 'Theme used in back-end';
$lang['system']['MODULES_SETTINGS'] = 'Modules activation';
$lang['system']['MOD_THEME'] = 'Theme module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_SCALE'] = 'Scale module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_LEVEL'] = 'Level module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_USER'] = 'Users module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_NEWSLETTER'] = 'Newsletter module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_NEWS'] = 'News module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PROJECT'] = 'Projects module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_YELLOWPAGES'] = 'Directory module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_WORKSHOP'] = 'Workgroup module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PUBLICATION'] = 'Publication module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_SDI'] = 'Indicators module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_DASHBOARD'] = 'Dashboard module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_SYSTEM'] = 'System configuration module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PLUGINS'] = 'Plugins module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PAGE'] = 'Pages module activation | default : 0 | option : 0 / 1';
$lang['system']['MOD_LIBRARY'] = 'Library module activation | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_SETTINGS'] = 'Comments settings';
$lang['system']['COMMENT_MODULES'] = 'Enabled for modules | default : news,project,publication,report,indicator,files,contribute';
$lang['system']['COMMENT_MODERATION'] = 'Enable moderation | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_NOTIFICATION'] = 'Enable email notification | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_MODERATE_REGISTERED'] = 'Enable moderation for registered users  | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_ONLY_REGISTERED'] = 'Enable comments only for registered users | default : 1 | option : 0 / 1';
$lang['system']['DEBUG_SETTINGS'] = 'Debug set up';
$lang['system']['MOD_DEBUG'] = "Debug activation | default : 0 | option : 0 / 1";
$lang['system']['SQL_LOG_DEBUG'] = "SQL log file debug  | default : 0 | option : 0 / 1";
$lang['system']['SYSTEM_SETTINGS'] = 'Settings utilities';
$lang['system']['PHOTO_RESIZE'] = 'Resize photo activation | default : 1 | option : 0 / 1';
$lang['system']['RICH_TEXT_EDITOR'] = 'Rich text edition activation | default : \'cke\' | option : 0 / \'cke\' / \'tinymce\' ';
$lang['system']['AUTO_LINK'] = 'Auto Link content in text fields | default : 1 | option : 0 / 1 ';
$lang['system']['TIMELINE_DISPLAY'] = 'Projects timeline activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_REWRITE'] = 'URL rewriting activation | default : 1 | option : 0 / 1';
$lang['system']['URI_SEPARATOR'] = 'URL Rewriting separator | default : / | option : / _ or others delimiters (be aware)';
$lang['system']['UPLOAD_METHOD'] = 'Files upload | default : HTTP | option : HTTP / FTP (not implemented yet)';
$lang['system']['SQL'] = 'SQL server type | default : mysql | option : mysql / pgsql';
$lang['system']['PASSWD_MINLENGTH'] = 'Password minimum length | default : 6';
$lang['system']['SALT_CRYPT'] = 'Salt crypt | default : ld';
$lang['system']['CHECK_LINK'] = 'Documents and links check activation | default : 0 | option : 0 / 1';
$lang['system']['SURFACE_UNIT'] = 'Surface unit | default : km<sup>2</sup> | option : free';
$lang['system']['ALLOWABLE_TAGS'] = "Authorized HTML elements strip_slashes | default : <a><abbr><accronym><u><strong><em> ";
$lang['system']['END_LINE'] = "End line character | default : \n";
$lang['system']['TAB_LINE'] = "Tabulation character | default : \t";
$lang['system']['OUTPUT_SEP'] = "URL output separator | default : &amp;";
$lang['system']['AREA_SETTINGS'] = "Textarea size | default : rows='' cols='' ";
$lang['system']['ERROR_SYSTEM'] = "Error system message | default : ::sytem_error:: ";
$lang['system']['CONFIRM_REFRESH'] = "Confirmation message time in seconds (before refresh) | default : 1 ";
$lang['system']['UPLOAD_MAX_MO'] = "Upload maximum size unit octet | default : 512000 ";
$lang['system']['MAX_PHOTO_MAX_WIDTH'] = "Maximum width for a picture unit px | default : 600 ";
$lang['system']['MAX_PHOTO_MIN_WIDTH'] = "Minimum width for a picture unit px| default : 160  ";
$lang['system']['MAIL_INFORMATIONS'] = 'Informations and set up of mail sending';
$lang['system']['MAIL_SENDMAIL'] = 'Sendmail path | default :  /usr/sbin/sendmail -t -i';
$lang['system']['MAIL_HOST'] = "Mailer host | default : your.smtp.net";
$lang['system']['MAIL_PORT'] = "Mailer port | default : 25";
$lang['system']['MAIL_SETTINGS'] = 'Mail Settings';
$lang['system']['MAIL_MAILER'] = "Mailer type | default : sendmail";
$lang['system']['MAIL_SMTP_AUTH'] = "Mailer authentication activation | default : 0 | option : 0 / 1";
$lang['system']['MAIL_SMTP_USER'] = "User for mailer | default : smtpUser";
$lang['system']['MAIL_SMTP_PASS'] = "Password for mailer | default : smtpPass";
$lang['system']['MAIL_FROM'] = "From mail for sending mails | default : admin@your-collectivity.com";
$lang['system']['MAIL_FROMNAME'] = "Name mail for sending mails | default : Administrator your-collectivity.com";
$lang['system']['MAIL_REPLY'] = "Reply mail for sending mails | default : admin@your-collectivity.com";
$lang['system']['MAIL_REPLYNAME'] = "Reply name for sending mails | default : Administrator your-collectivity";
$lang['system']['ALERT_DIRECTORY'] = "Mail sending for subscribe/unsubscribe from the organisations directory | default : 1 | option : 0 / 1";
$lang['system']['SERVER_SETTINGS'] = 'Application Server settings';
$lang['system']['SITE_LINEA_NAME'] = "Software editor name";
$lang['system']['SITE_LINEA_URL'] = "Software editor website";
$lang['system']['MAIL_LINEA'] = "Software editor mail";
$lang['system']['SITE_NAME'] = "Website name | default : Website Name";
$lang['system']['SITE_ROOT_URL'] = "Site root URL | default : http://www.yourwebsite.com";
$lang['system']['SITE_MAIL'] = "Site mail | default : info@yourwebsite.com";
$lang['system']['SUPPORT_SETTINGS'] = 'Support settings';
$lang['system']['SUPPORT_LINEA'] = 'Online support website | default : http://dev.linea21.com/';
$lang['system']['MAIL_ADMIN_LINEA'] = 'Linea 21 administrator mail | default : info@linea21.com';
$lang['system']['LOGS_SETTINGS'] = 'Logs settings';
$lang['system']['LOG_ADMIN_ACCESS'] = "Admin access log path | default : ../logs/access.admin.log";
$lang['system']['LOG_PUBLIC_ACCESS'] = "Public access log path | default : ../logs/access.public.log";
$lang['system']['LOG_KEYWORDS'] = "Keywords log path | default : ../logs/keywords.log";
$lang['system']['LOG_MAILING'] = "Mailing log path | default : ../logs/mailing.log";
$lang['system']['LOG_MAILER'] = "Mailer log path | default : ../logs/mailer.log";
$lang['system']['LOG_SQL_QUERIES'] = "Sql queries log path | default : ../logs/sql_queries.log";
$lang['system']['LOG_SQL_ERRORS'] = "Sql errors log path | default : ../logs/sql_errors.log";
$lang['system']['SITE_PATH'] = "Application server path | default : path/to/linea ";
$lang['system']['DATE_FORMAT'] = "Date format | default : dd-mm-yyyy | option : dd-mm-yyyy / yyyy-mm-dd ";
$lang['system']['TIME_FORMAT'] = "Time format | default : 24 | option : 12 / 24 ";
$lang['system']['MOD_DEBUG'] = "Debug Mode activation | default : 0 | option : 0 / 1";
$lang['system']['THEME_LIST_PUBLIC'] = "List of available theme for public site| default : linea21 | option : seperate theme by | ";
$lang['system']['THEME_LIST_ADMIN'] = "List of available theme for admin site| default : default | option : seperate theme by | ";
$lang['system']['LANGUAGE_SETTINGS'] = "Language settings";
$lang['system']['LOCALES_SETTINGS'] = "Date and time format settings";
$lang['system']['NOTIFICATION_SETTINGS'] = 'Notifications settings - Emails';
$lang['system']['ALERT_NEWFILE'] = 'New files notification | default : 2 | options : 0 / 1 / 2';
$lang['system']['ALERT_NEWTOPIC'] = 'New topics notification | default : 2 | options : 0 / 1 / 2';
$lang['system']['ALERT_NEWPOST'] = 'New posts notification | default : 2 | options : 0 / 1 / 2';
$lang['system']['ALERT_NEWEVENT'] = 'New events notification | default : 2 | options : 0 / 1 / 2';

$lang['sys_theme']['theme_editor'] ="Theme editor";
$lang['sys_theme']['confirm_edit'] ="The file was successfully modified.";
$lang['sys_theme']['not_accessible'] ="The file does not exist or is not readable.";
$lang['sys_theme']['not_writable'] ="The file is not writable. Please, change permissions to be able to edit it.";
$lang['sys_theme']['edit_public'] ="Edit public theme";
$lang['sys_theme']['edit_file'] ="Edit file";
$lang['sys_theme']['files'] ="Files";
$lang['sys_theme']['current_file'] = "Current file";
?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/en/lang_system.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$lang['theme']['name']='Name';
$lang['theme']['author']='Author';
$lang['theme']['version']='Version';
$lang['theme']['compatibility']='Compatibility';
$lang['theme']['description']='Description';

$lang['upload']['CheckExtImage'] = "Upload not allowed. Please, check the extension";
$lang['upload']['upload_size'] = "The file you want to upload is too big. Maximal size is  : %s";
$lang['upload']['wrong_ext'] = "File type not allowed.<br />See allowed extensions : <em>%s</em>";
$lang['upload']['confirmed'] = "Upload successful";
$lang['upload']['error'] = "Unexpected upload error.";
$lang['upload']['addfiles'] = "Add files";

$lang['upload']['prohibited_transfert'] = "Transfer method is forbidden";
$lang['upload']['file_exist_yet'] = "File already exists";

$lang['upload']['ftp_conn_failed'] = "FTP connexion failed";
$lang['upload']['ftp_user'] ='ftp_user';
$lang['upload']['ftp_conn'] ='FTP connexion try';
$lang['upload']['ftp_transfert_error'] ='FTP transfer error';

$lang['upload']['no_resize'] ='Document is not a resizable picture.';

$lang['system']['mod']="Edit settings";
$lang['system']['title_theme']='interface theme (look and feel)';
$lang['system']['title_release']='Global settings';
$lang['system']['title_db']='Database settings';
$lang['system']['title_php_info']='PHP Settings (read only)';
$lang['system']['confirm_mod'] = "Configuration file successfully updated\n";
$lang['system']['help_list1']="Click on settings parameter to display more informations";
$lang['system']['help_list2']="Edit parameters by clicking on the edit icon linked in";
$lang['system']['help_list3']="To perform search, just click the 'search' link";
$lang['system']['list']= "Settings list";
$lang['system']['help_mod1']="To edit a parameter, please insert the required informations in the form above";
$lang['system']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['system']['help_mod3']="After checking summary, click the \'review settings\' button to make changes";
$lang['system']['permission_check']="Permissions check";
$lang['system']['permission_writable']="Write permissions on %s folder";
$lang['system']['permission_ok']="Authorized";
$lang['system']['permission_warn']="Unauthorized";

//traductions pour les fichiers de configuration config_db et config_release

$lang['system']['DB_HOST'] ="Database host, default : localhost";
$lang['system']['DB_USER'] = "Database user, default : linea";
$lang['system']['DB_PASS'] = "Database password, default : linea";
$lang['system']['DB_NAME'] = "Database base name, default : linea";
$lang['system']['DB_ADMINMAIL'] = "Database administrator email | default : -1 | option : -1 / adress@email.com";
$lang['system']['DATABASE'] = "T_ : primary table prefix / J_ : join table prefix";
$lang['system']['RELEASE_SETTINGS'] = 'Global settings';
$lang['system']['LINEA_VERSION'] = 'Linea21 version';
$lang['system']['U_L'] = 'Language | default : fr | option : en / fr';
$lang['system']['CHARSET'] = 'Charset encoding | default : utf-8 | option : utf-8';
$lang['system']['USER_COMMUNITY'] = 'Community id number';
$lang['system']['SELECT_LIMIT'] = 'Maximum limit for query select | default : 20';
$lang['system']['MAX_SCALE_LEVEL'] = 'Maximum scale level | default : 5';
$lang['system']['THEME_PUBLIC'] = 'Theme used in front-end';
$lang['system']['THEME_ADMIN'] = 'Theme used in back-end';
$lang['system']['MODULES_SETTINGS'] = 'Modules activation';
$lang['system']['MOD_THEME'] = 'Theme module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_SCALE'] = 'Scale module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_LEVEL'] = 'Level module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_USER'] = 'Users module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_NEWSLETTER'] = 'Newsletter module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_NEWS'] = 'News module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PROJECT'] = 'Projects module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_YELLOWPAGES'] = 'Directory module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_WORKSHOP'] = 'Workgroup module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PUBLICATION'] = 'Publication module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_SDI'] = 'Indicators module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_DASHBOARD'] = 'Dashboard module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_SYSTEM'] = 'System configuration module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PLUGINS'] = 'Plugins module activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_PAGE'] = 'Pages module activation | default : 0 | option : 0 / 1';
$lang['system']['MOD_LIBRARY'] = 'Library module activation | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_SETTINGS'] = 'Comments settings';
$lang['system']['COMMENT_MODULES'] = 'Enabled for modules | default : news,project,publication,report,indicator,files,contribute';
$lang['system']['COMMENT_MODERATION'] = 'Enable moderation | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_NOTIFICATION'] = 'Enable email notification | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_MODERATE_REGISTERED'] = 'Enable moderation for registered users  | default : 1 | option : 0 / 1';
$lang['system']['COMMENT_ONLY_REGISTERED'] = 'Enable comments only for registered users | default : 1 | option : 0 / 1';
$lang['system']['DEBUG_SETTINGS'] = 'Debug set up';
$lang['system']['MOD_DEBUG'] = "Debug activation | default : 0 | option : 0 / 1";
$lang['system']['SQL_LOG_DEBUG'] = "SQL log file debug  | default : 0 | option : 0 / 1";
$lang['system']['SYSTEM_SETTINGS'] = 'Settings utilities';
$lang['system']['PHOTO_RESIZE'] = 'Resize photo activation | default : 1 | option : 0 / 1';
$lang['system']['RICH_TEXT_EDITOR'] = 'Rich text edition activation | default : \'cke\' | option : 0 / \'cke\' / \'tinymce\' ';
$lang['system']['AUTO_LINK'] = 'Auto Link content in text fields | default : 1 | option : 0 / 1 ';
$lang['system']['TIMELINE_DISPLAY'] = 'Projects timeline activation | default : 1 | option : 0 / 1';
$lang['system']['MOD_REWRITE'] = 'URL rewriting activation | default : 1 | option : 0 / 1';
$lang['system']['URI_SEPARATOR'] = 'URL Rewriting separator | default : / | option : / _ or others delimiters (be aware)';
$lang['system']['UPLOAD_METHOD'] = 'Files upload | default : HTTP | option : HTTP / FTP (not implemented yet)';
$lang['system']['SQL'] = 'SQL server type | default : mysql | option : mysql / pgsql';
$lang['system']['PASSWD_MINLENGTH'] = 'Password minimum length | default : 6';
$lang['system']['SALT_CRYPT'] = 'Salt crypt | default : ld';
$lang['system']['CHECK_LINK'] = 'Documents and links check activation | default : 0 | option : 0 / 1';
$lang['system']['SESS_INACTIVITY_MAXTIME'] = 'Session max time inactivity before logout (in seconds)  | default : 1800 (30 min.) | option : free';
$lang['system']['USER_LOGIN_CHANGE'] = 'Number of times user is allowed to change himself his login  | default : 0 | option : free (integer)';
$lang['system']['REMEMBER_ME'] = 'Remember me settings (in seconds) | default : 2592000 (30 days) | option : free (0, disabled)';
$lang['system']['MEDIA_ALLOWED_EXT'] = 'Allowable extensions for upload  | default : zip,rar,txt,xls,xlsx,ppt,pps,pptx,ppsx,jpg,jpeg,png,gif,svg,doc,docx,rtf,pdf,odt,ods | option : free';
$lang['system']['MEDIA_ALLOWED_SIZE'] = 'Maximum file size for upload | default : 8388608 (8 Mb) | option : free';
$lang['system']['NEWSLETTER_AUTO_SUB'] = 'Auto-subscribe to newsletter | default : 1 | option : 0 / 1';
$lang['system']['SURFACE_UNIT'] = 'Surface unit | default : km<sup>2</sup> | option : free';
$lang['system']['ALLOWABLE_TAGS'] = "Authorized HTML elements strip_slashes | default : <a><abbr><accronym><u><strong><em> ";
$lang['system']['END_LINE'] = "End line character | default : \n";
$lang['system']['TAB_LINE'] = "Tabulation character | default : \t";
$lang['system']['OUTPUT_SEP'] = "URL output separator | default : &amp;";
$lang['system']['AREA_SETTINGS'] = "Textarea size | default : rows='' cols='' ";
$lang['system']['ERROR_SYSTEM'] = "Error system message | default : ::sytem_error:: ";
$lang['system']['CONFIRM_REFRESH'] = "Confirmation message time in seconds (before refresh) | default : 1 ";
$lang['system']['UPLOAD_MAX_MO'] = "Upload maximum size unit octet | default : 512000 ";
$lang['system']['MAX_PHOTO_MAX_WIDTH'] = "Maximum width for a picture unit px | default : 600 ";
$lang['system']['MAX_PHOTO_MIN_WIDTH'] = "Minimum width for a picture unit px| default : 160  ";
$lang['system']['MAIL_INFORMATIONS'] = 'Informations and set up of mail sending';
$lang['system']['MAIL_SENDMAIL'] = 'Sendmail path | default :  /usr/sbin/sendmail -t -i';
$lang['system']['MAIL_HOST'] = "Mailer host | default : your.smtp.net";
$lang['system']['MAIL_PORT'] = "Mailer port | default : 25";
$lang['system']['MAIL_SETTINGS'] = 'Mail Settings';
$lang['system']['MAIL_MAILER'] = "Mailer type | default : sendmail";
$lang['system']['MAIL_SMTP_AUTH'] = "Mailer authentication activation | default : 0 | option : 0 / 1";
$lang['system']['MAIL_SMTP_USER'] = "User for mailer | default : smtpUser";
$lang['system']['MAIL_SMTP_PASS'] = "Password for mailer | default : smtpPass";
$lang['system']['MAIL_FROM'] = "From mail for sending mails | default : admin@your-collectivity.com";
$lang['system']['MAIL_FROMNAME'] = "Name mail for sending mails | default : Administrator your-collectivity.com";
$lang['system']['MAIL_REPLY'] = "Reply mail for sending mails | default : admin@your-collectivity.com";
$lang['system']['MAIL_REPLYNAME'] = "Reply name for sending mails | default : Administrator your-collectivity";
$lang['system']['ALERT_DIRECTORY'] = "Mail sending for subscribe/unsubscribe from the organisations directory | default : 1 | option : 0 / 1";
$lang['system']['SERVER_SETTINGS'] = 'Application Server settings';
$lang['system']['SITE_LINEA_NAME'] = "Software editor name";
$lang['system']['SITE_LINEA_URL'] = "Software editor website";
$lang['system']['MAIL_LINEA'] = "Software editor mail";
$lang['system']['SITE_NAME'] = "Website name | default : Website Name";
$lang['system']['SITE_ROOT_URL'] = "Site root URL | default : http://www.yourwebsite.com";
$lang['system']['SITE_MAIL'] = "Site mail | default : info@yourwebsite.com";
$lang['system']['SUPPORT_SETTINGS'] = 'Support settings';
$lang['system']['SUPPORT_LINEA'] = 'Online support website | default : http://dev.linea21.com/';
$lang['system']['MAIL_ADMIN_LINEA'] = 'Linea 21 administrator mail | default : info@linea21.com';
$lang['system']['LOGS_SETTINGS'] = 'Logs settings';
$lang['system']['LOG_ADMIN_ACCESS'] = "Admin access log path | default : ../logs/access.admin.log";
$lang['system']['LOG_PUBLIC_ACCESS'] = "Public access log path | default : ../logs/access.public.log";
$lang['system']['LOG_KEYWORDS'] = "Keywords log path | default : ../logs/keywords.log";
$lang['system']['LOG_MAILING'] = "Mailing log path | default : ../logs/mailing.log";
$lang['system']['LOG_MAILER'] = "Mailer log path | default : ../logs/mailer.log";
$lang['system']['LOG_SQL_QUERIES'] = "Sql queries log path | default : ../logs/sql_queries.log";
$lang['system']['LOG_SQL_ERRORS'] = "Sql errors log path | default : ../logs/sql_errors.log";
$lang['system']['SITE_PATH'] = "Application server path | default : path/to/linea ";
$lang['system']['DATE_FORMAT'] = "Date format | default : dd-mm-yyyy | option : dd-mm-yyyy / yyyy-mm-dd ";
$lang['system']['TIME_FORMAT'] = "Time format | default : 24 | option : 12 / 24 ";
$lang['system']['MOD_DEBUG'] = "Debug Mode activation | default : 0 | option : 0 / 1";
$lang['system']['THEME_LIST_PUBLIC'] = "List of available theme for public site| default : linea21 | option : seperate theme by | ";
$lang['system']['THEME_LIST_ADMIN'] = "List of available theme for admin site| default : default | option : seperate theme by | ";
$lang['system']['LANGUAGE_SETTINGS'] = "Language settings";
$lang['system']['LOCALES_SETTINGS'] = "Date and time format settings";
$lang['system']['NOTIFICATION_SETTINGS'] = 'Notifications settings - Emails';
$lang['system']['ALERT_NEWFILE'] = 'New files notification | default : 2 | options : 0 / 1 / 2';
$lang['system']['ALERT_NEWTOPIC'] = 'New topics notification | default : 2 | options : 0 / 1 / 2';
$lang['system']['ALERT_NEWPOST'] = 'New posts notification | default : 2 | options : 0 / 1 / 2';
$lang['system']['ALERT_NEWEVENT'] = 'New events notification | default : 2 | options : 0 / 1 / 2';

$lang['sys_theme']['theme_editor'] ="Theme editor";
$lang['sys_theme']['confirm_edit'] ="The file was successfully modified.";
$lang['sys_theme']['not_accessible'] ="The file does not exist or is not readable.";
$lang['sys_theme']['not_writable'] ="The file is not writable. Please, change permissions to be able to edit it.";
$lang['sys_theme']['edit_public'] ="Edit public theme";
$lang['sys_theme']['edit_file'] ="Edit file";
$lang['sys_theme']['files'] ="Files";
$lang['sys_theme']['current_file'] = "Current file";
?>
